@@ -2,8 +2,9 @@ from oc4idskit.cli.__main__ import main
 from tests import assert_streaming
 
 
-def test_command(monkeypatch):
+def test_command(capsys, monkeypatch):
     assert_streaming(
+        capsys,
         monkeypatch,
         main,
         ["split-project-packages", "1"],
