@@ -10,6 +10,4 @@ logger.setLevel(logging.WARNING)
 
 @pytest.fixture()
 def vcr_cassette_name(request):
-    return "{}-{}".format(
-        os.path.splitext(os.path.basename(request.node.fspath))[0], request.node.name
-    )
+    return f"{os.path.splitext(os.path.basename(request.node.fspath))[0]}-{request.node.name}"
